@@ -1,9 +1,8 @@
-use 5.008001;
-use strict;
+use v5.12.0;
 use warnings;
-package Email::MIME::Creator;
+package Email::MIME::Creator 1.954;
 # ABSTRACT: obsolete do-nothing library
-$Email::MIME::Creator::VERSION = '1.940';
+
 use parent q[Email::Simple::Creator];
 use Email::MIME;
 use Encode ();
@@ -44,19 +43,29 @@ Email::MIME::Creator - obsolete do-nothing library
 
 =head1 VERSION
 
-version 1.940
+version 1.954
 
 =head1 SYNOPSIS
 
 You don't need to use this module for anything.
 
+=head1 PERL VERSION
+
+This library should run on perls released even a long time ago.  It should
+work on any version of perl released in the last five years.
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to
+lower the minimum required perl.
+
 =head1 AUTHORS
 
 =over 4
 
 =item *
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES <cpan@semiotic.systems>
 
 =item *
 
